"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.HttpCacheSchema = void 0;
const zod_1 = require("zod");
const invalidFieldsMsg = 'Cache object should have `etag` or `lastModified` fields';
exports.HttpCacheSchema = zod_1.z
    .object({
    // TODO: remove this migration part during the Christmas eve 2024
    timeStamp: zod_1.z.string().optional(),
    timestamp: zod_1.z.string().optional(),
})
    .passthrough()
    .transform((data) => {
    if (data.timeStamp) {
        data.timestamp = data.timeStamp;
        delete data.timeStamp;
    }
    return data;
})
    .pipe(zod_1.z
    .object({
    etag: zod_1.z.string().optional(),
    lastModified: zod_1.z.string().optional(),
    httpResponse: zod_1.z.unknown(),
    timestamp: zod_1.z.string(),
})
    .refine(({ etag, lastModified }) => etag ?? lastModified, invalidFieldsMsg))
    .nullable()
    .catch(null);
//# sourceMappingURL=schema.js.map